@@ -42,6 +42,7 @@ module Network.AWS.CodeDeploy.GetApplication
     , garApplication
     ) where
 
+import Network.AWS.Data (Object)
 import Network.AWS.Prelude
 import Network.AWS.Request.JSON
 import Network.AWS.CodeDeploy.Types
@@ -63,8 +64,8 @@ getApplication p1 = GetApplication
     { _gaApplicationName = p1
     }
 
--- | The name of an existing AWS CodeDeploy application within the AWS user
--- account.
+-- | The name of an existing AWS CodeDeploy application associated with the
+-- applicable IAM user or AWS account.
 gaApplicationName :: Lens' GetApplication Text
 gaApplicationName =
     lens _gaApplicationName (\s a -> s { _gaApplicationName = a })
